#========================================================================================
# package      DE_EPAGES::GoogleSmartShopping::API::Constants
# state        public
#----------------------------------------------------------------------------------------
# description  This is the place for common GoogleSmartShopping values and constants.
#========================================================================================
package DE_EPAGES::GoogleSmartShopping::API::Constants;
use base Exporter;

use strict;

our @EXPORT_OK = qw (
    ACCOUNT_ISSUE_TRANSLATION_KEYS
    GOOGLE_SMART_SHOPPING_APP_SCOPES
    GOOGLE_ERROR_CODES
    EPAGESJ_BASE_URI
    MERCHANT_CENTER_REQUIREMENTS_CHECK_LIST
    ERROR_UNKNOWN
    ERROR_FORM_SUBMIT
    ERROR_ACCEPT_TERMS
    ERROR_TOKEN_EXPIRED_OR_REVOKED
    ERROR_GET_VERIFICATION_TOKEN_FAILED
    ERROR_UNAUTHENTICATED
    ERROR_CONFLICTING_CLAIM
    ERROR_FORBIDDEN
    ERROR_ACCESS_DENIED
    ERROR_CONFLICT
    ERROR_VALIDATION
    ERROR_RATE_LIMIT
    ERROR_NOT_INSERTED
    ERROR_NOT_FOUND
    ERROR_TOO_MANY
    ERROR_TOO_MANY_ITEMS
    ERROR_TOO_MANY_SUBACCOUNTS
    ERROR_REQUEST_RATE_TOO_HIGH
    ERROR_DAILY_LIMIT_EXCEEDED
    ERROR_TOO_MANY_FAILED_AUTHS
    ERROR_INVALID_REQUEST
    ERROR_INVALID_TOKEN
    ERROR_INTERNAL_GOOGLE
);

use constant GOOGLE_SMART_SHOPPING_APP_SCOPES => qw (
    https://www.googleapis.com/auth/content
    https://www.googleapis.com/auth/siteverification
    https://www.googleapis.com/auth/adwords
    https://www.googleapis.com/auth/userinfo.email
);

use constant EPAGESJ_BASE_URI =>  'misc/google-smart-shopping/';

use constant MERCHANT_CENTER_REQUIREMENTS_CHECK_LIST => qw (
    ChecklistContactInfo
    ChecklistReturnPolicy
    ChecklistBillingTOC
    ChecklistGoogleAdsPolicies
    ChecklistCookieNotice
);

use constant ERROR_UNKNOWN                          => 'unknown_error';
use constant ERROR_FORM_SUBMIT                      => 'form_submit_failed';
use constant ERROR_ACCEPT_TERMS                     => 'not_accepted_terms';
use constant ERROR_TOKEN_EXPIRED_OR_REVOKED         => 'token_expired_or_revoked';
use constant ERROR_GET_VERIFICATION_TOKEN_FAILED    => 'timed_out';
use constant ERROR_UNAUTHENTICATED                  => 'not_authenticated';
use constant ERROR_CONFLICTING_CLAIM                => 'already_claimed';
use constant ERROR_FORBIDDEN                        => 'forbidden';
use constant ERROR_ACCESS_DENIED                    => 'access_denied';
use constant ERROR_CONFLICT                         => 'conflict';
use constant ERROR_VALIDATION                       => 'validation';
use constant ERROR_RATE_LIMIT                       => 'rate_limit';
use constant ERROR_REQUIRED_FIELD                   => 'required_field';
use constant ERROR_NOT_INSERTED                     => 'not_inserted';
use constant ERROR_NOT_FOUND                        => 'not_found';
use constant ERROR_TOO_MANY_ITEMS                   => 'too_many_items';
use constant ERROR_TOO_MANY_SUBACCOUNTS             => 'too_many_subaccounts';
use constant ERROR_REQUEST_RATE_TOO_HIGH            => 'request_rate_too_high';
use constant ERROR_DAILY_LIMIT_EXCEEDED             => 'daily_limit_exceeded';
use constant ERROR_TOO_MANY_FAILED_AUTHS            => 'too_many_failed_auths';
use constant ERROR_INVALID_REQUEST                  => 'invalid_request';
use constant ERROR_INVALID_TOKEN                    => 'invalid_token';
use constant ERROR_INTERNAL_GOOGLE                  => 'internal_google';

use constant GOOGLE_ERROR_CODES => {
    'invalid'                       => ERROR_INVALID_REQUEST,
    'invalid_token'                 => ERROR_INVALID_TOKEN,
    'authError'                     => ERROR_UNAUTHENTICATED,
    'auth/account_access_denied'    => ERROR_ACCESS_DENIED,
    'conflict'                      => ERROR_CONFLICT,
    'internalError'                 => ERROR_INTERNAL_GOOGLE,
    'required'                      => ERROR_REQUIRED_FIELD,
    'userRateLimitExceeded'         => ERROR_RATE_LIMIT,
    'validation'                    => ERROR_VALIDATION,
    'not_inserted'                  => ERROR_NOT_INSERTED,
    'notFound'                      => ERROR_NOT_FOUND,
    'quota/too_many_items'          => ERROR_TOO_MANY_ITEMS,
    'quota/too_many_subaccounts'    => ERROR_TOO_MANY_SUBACCOUNTS,
    'quota/request_rate_too_high'   => ERROR_REQUEST_RATE_TOO_HIGH,
    'quota/daily_limit_exceeded'    => ERROR_DAILY_LIMIT_EXCEEDED,
    'quota/too_many_failed_auths'   => ERROR_TOO_MANY_FAILED_AUTHS,
};

use constant ACCOUNT_ISSUE_TRANSLATION_KEYS => {
    'pending_address_and_phone'                                         => 'AccountLevelIssuePendingAddressAndPhone',
    'pending_phone_verification'                                        => 'AccountLevelIssuePendingPhoneVerification',
    'missing_ad_words_link'                                             => 'AccountLevelIssueMissingAdsAcccountLink',
    'invalid_store_name'                                                => 'AccountLevelIssueInvalidStoreName',
    'merchant_quality_low'                                              => 'AccountLevelIssueMerchantQualityLow',
    'editorial_and_professional_standards_destination_url_down_policy'  => 'AccountSuspendedDueToNonWorkingLandingPage',
};

1;
