#========================================================================================
# package      DE_EPAGES::GoogleSmartShopping::API::ScriptTagService
# state        public
#----------------------------------------------------------------------------------------
# description  GoogleSmartShoppingScriptTagService class
#========================================================================================
package DE_EPAGES::GoogleSmartShopping::API::ScriptTagService;

use DE_EPAGES::GoogleSmartShopping::API::Tools qw ( LogGoogleSmartShopping );
use DE_EPAGES::AppStore::API::Shop qw ( GetUnityScriptTagsApp );

use strict;

use constant VIEWACTION_GOOGLE_SMART_SHOPPING => '?ViewAction=UnityViewGoogleSmartShoppingScript';

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::GoogleSmartShopping::API::ScriptTagService->new( $hSettings );
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::GoogleSmartShopping::API::ScriptTagService
#========================================================================================
sub new {
    my $class = shift;
    my ($hSettings)  = @_;

    my $self  = bless {
        Shop => $hSettings->{'Shop'},
    }, $class;

    return $self;
}

#========================================================================================
# function     addScriptTag
#----------------------------------------------------------------------------------------
# syntax       $ScriptTagService->addScriptTag();
#----------------------------------------------------------------------------------------
# description  Inserts script tag for Unity shops
#========================================================================================
sub addScriptTag {
    my $self = shift;
    my $Shop = $self->{'Shop'};

    return unless $Shop->get('IsUnityRegistered');

    # get app client to communicate with the epagesJ REST API
    my $AppsClient = GetUnityScriptTagsApp($Shop);

    my $GoogleSmartShoppingScriptTagUrl = $self->_getGoogleSmartShoppingScriptTagUrl();

    # post new script tag, in case there has not been any so far
    $AppsClient->addScriptTag($GoogleSmartShoppingScriptTagUrl);

    LogGoogleSmartShopping('Added Script Tag for GoogleSmartShopping', {'ScriptTagUrl' => $GoogleSmartShoppingScriptTagUrl});

    return;
}

#========================================================================================
# function     deleteScriptTag
#----------------------------------------------------------------------------------------
# syntax       GoogleSmartShoppingScriptTagService->deleteScriptTag();
#----------------------------------------------------------------------------------------
# description  Deletes script tag for Unity shops
#========================================================================================
sub deleteScriptTag {
    my $self = shift;

    my $Shop = $self->{'Shop'};

    return unless $Shop->get('IsUnityRegistered');

    # get app client to communicate with the epagesJ REST API
    my $AppsClient = GetUnityScriptTagsApp($Shop);

    my $GoogleSmartShoppingScriptTagUrl = $self->_getGoogleSmartShoppingScriptTagUrl();

    # delete existing script-tag
    $AppsClient->deleteScriptTag($GoogleSmartShoppingScriptTagUrl);

    LogGoogleSmartShopping('Removed Script Tag for GoogleSmartShopping', {'ScriptTagUrl' => $GoogleSmartShoppingScriptTagUrl});

     return;
}

#----------------------------------------------------------------------------------------
sub _getGoogleSmartShoppingScriptTagUrl {
    my $self = shift;

    return $self->{'Shop'}->get('WebServerScriptName') . VIEWACTION_GOOGLE_SMART_SHOPPING;
}

1;
