#========================================================================================
# package      DE_EPAGES::GoogleSmartShopping::t::unit::ScriptTagService
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for API::ScriptTagService
#========================================================================================
package DE_EPAGES::GoogleSmartShopping::t::unit::ScriptTagService;
use base DE_EPAGES::Core::API::Test;

use strict;

use DE_EPAGES::Core::API::Object::DateTimeFormatter;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;

use Test::Exception;
use Test::Mockify;
use Test::Mockify::Sut;
use Test::Mockify::Verify qw ( WasCalled );
use Test::More;

use constant WEBSERVER_SCRIPT_NAME => 'WebServerScriptName.de\\';

sub test {
    my $self = shift;

    $self->test_addScriptTag_success();
    $self->test_addScriptTag_notUnity();

    $self->test_deleteScriptTag_success();
    $self->test_deleteScriptTag_notUnity();

    done_testing();
}

#----------------------------------------------------------------------------------------
sub test_addScriptTag_success {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '1';

    my $MockedShop = $self->_createShop($IsUnityRegistered);

    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedShop);

    lives_ok(sub { $SUT->addScriptTag() }, "$SubTestName - tests if 'addScriptTag' does not die");

    ok( WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was called");

    is( $MockedScriptTagAppClient->call_pos(1),'addScriptTag',  "$SubTestName - 'addScriptTag' was called" );

    is( ($MockedScriptTagAppClient->call_args(1))[1],
        WEBSERVER_SCRIPT_NAME.'?ViewAction=UnityViewGoogleSmartShoppingScript',
        "$SubTestName - ScriptTag Url passed to 'addScriptTag' is correct" );
}

sub test_addScriptTag_notUnity {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '0';

    my $MockedShop = $self->_createShop($IsUnityRegistered);
    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedShop);

    lives_ok(sub { $SUT->addScriptTag() }, "$SubTestName - tests if 'addScriptTag' does not die");

    ok(!WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was not called");
}

sub test_deleteScriptTag_success {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '1';

    my $MockedShop = $self->_createShop($IsUnityRegistered);
    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedShop);

    lives_ok(sub { $SUT->deleteScriptTag() }, "$SubTestName - tests if 'deleteScriptTag' does not die");

    ok( WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was called");

    is( $MockedScriptTagAppClient->call_pos(1),'deleteScriptTag',  "$SubTestName - 'deleteScriptTag' was called" );

    is( ($MockedScriptTagAppClient->call_args(1))[1],
        WEBSERVER_SCRIPT_NAME.'?ViewAction=UnityViewGoogleSmartShoppingScript',
        "$SubTestName - ScriptTag Url passed to 'deleteScriptTag' is correct" );

}

sub test_deleteScriptTag_notUnity {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '0';

    my $MockedShop = $self->_createShop($IsUnityRegistered);
    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedShop);

    lives_ok(sub { $SUT->deleteScriptTag() }, "$SubTestName - tests if 'deleteScriptTag' does not die");

    ok(!WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was not called");
}

#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;
    my ($MockedScriptTagAppClient, $MockedShop) = @_;

    my $aParameterList = [{
        'Shop' => $MockedShop
    }];
    my $MockifySut = Test::Mockify::Sut->new('DE_EPAGES::GoogleSmartShopping::API::ScriptTagService', $aParameterList);

    $MockifySut->mockImported('DE_EPAGES::GoogleSmartShopping::API::Tools', 'LogGoogleSmartShopping')
        ->whenAny()
        ->thenReturnUndef();

    $MockifySut->mockImported('DE_EPAGES::AppStore::API::Shop', 'GetUnityScriptTagsApp')
        ->whenAny()
        ->thenReturn($MockedScriptTagAppClient);

    return $MockifySut->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createShop {
    my $self = shift;
    my ($IsUnityRegistered) = @_;

    my $hAttributes = {
        'ID' => '23456',
        'Alias' => 'NemoShop',
        'OrderProcess' => 1,
        'IsUnityRegistered' => $IsUnityRegistered,
        'WebServerScriptName' =>  WEBSERVER_SCRIPT_NAME,
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new( 'DE_EPAGES::Shop::API::Object::Shop', $hAttributes );
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createScriptTagAppClient {
    my $self = shift;

    my $mock = Test::MockObject->new();
    $mock->set_true( 'addScriptTag' );
    $mock->set_true( 'deleteScriptTag' );

    return $mock;
}
__PACKAGE__->runScript();

