use strict;
use Getopt::Long;
use Time::HiRes qw(time);
use DE_EPAGES::Core::API::Error qw(GetError ExistsError Error);
use DE_EPAGES::Core::API::Script qw(RunScript);
use DE_EPAGES::Core::API::Warning qw (Warning);
use DE_EPAGES::Database::API::Connection qw(RunOnStore);
use DE_EPAGES::Object::API::Factory qw(LoadObject LoadObjectByPath ExistsObject);
use DE_EPAGES::PriceList::API::PriceList qw (FillEmptyPriceListFields);
use DE_EPAGES::Shop::API::System qw(GetUnityShopIDs);
use DE_EPAGES::WebInterface::API::MessageCenter qw(SynchronizeCache);

sub Main {

    local $| = 1;

    my $ShopAlias;
    my $Password;
    my $StoreName;
    my $Help;

    GetOptions(
        'help'          => \$Help,
        'passwd=s'      => \$Password,
        'storename=s'   => \$StoreName,
        'shop=s'        => \$ShopAlias,
    );
    usage() if $Help;
    unless( $StoreName ) {
        print STDERR "Missing parameter -storename\n\n";
        usage();
    }

    my $time1 = time;

    my $aShopIDs = [];
    RunOnStore(
        Store      => $StoreName,
        DBPassword => $Password,
        Sub        => sub {
            unless ($ShopAlias) {
                $aShopIDs = GetUnityShopIDs();
            }
            else {
                my $Shop = LoadObjectByPath("/Shops")->child($ShopAlias);
                Error('Unknown Shop: ', $ShopAlias) if (!defined $Shop);
                push(@$aShopIDs, $Shop->id);
            }

            foreach my $ShopID (@$aShopIDs) {
                next unless ExistsObject($ShopID);
                my $Shop = LoadObject($ShopID);

                FillEmptyPriceListFields($Shop);
            }
        },
    );
    my $time2 = time;
    printf "need %.1f seconds\n", $time2 - $time1;
    eval { SynchronizeCache(); };
    Warning( GetError() ) if ExistsError();
    return;
}

sub usage {
    print <<END_USAGE;
Description:
   Fill empty fields for discounts, scaleprices and globalvalue discounts for customer specific pricelists.
Usage:
    perl $0 [options] [flags] datafiles
options:
    -passwd     database user password                          ()
    -storename  name of store                                   ()
    -shop       alias of shop                               ()
flags:
    -help       show the command line options
Example:
    perl $0 -storename Store
END_USAGE
    exit 2;
}

RunScript('Sub' => \&Main);