#========================================================================================
# package      DE_EPAGES::Tax::API::Resource::TaxModelResource
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for tax model details
#========================================================================================
package DE_EPAGES::Tax::API::Resource::TaxModelResource;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Core::API::Url qw (ParseQueryString);
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Shop::API::Resource::Formatter;
use DE_EPAGES::Shop::API::Constants qw ( TaxModel2Text TAX_MODEL_NET );

use feature 'switch';

use strict;



sub service {
    return LoadObjectByPath('/RestServices/TaxModel');
}



sub class {
    return 'Shop';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/tax-model/?$|;

    return 1;
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    given ($ActionName) {
        when( 'get' ) {
            my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
            my $LocaleID = $hQuery->{'locale'}->[0];
            return [ $Object, $LocaleID ];
        }
        default {
            return [$Object];
        }
    }
}



sub get {
    my $self = shift;
    my ($Shop, $LocaleID) = @_;

    my $Context = DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);

    $LocaleID = $Context->validLocale($LocaleID);
    my $Locale= DE_EPAGES::Object::API::Object::Locale->load($LocaleID);
    my $LanguageID = $Locale->get('LanguageID');
    my $Code2 = $Locale->get('Country')->{'Code2'};
    
    my $Formatter = DE_EPAGES::Shop::API::Resource::Formatter->new($Shop, $LocaleID);
    my $DisplayTaxes = $Shop->get('TaxModel') == TAX_MODEL_NET || !$Shop->get('VATreleased');

    return {
        'model'                     => TaxModel2Text($Shop->get('TaxModel')),
        'displayTaxes'              => $Formatter->bool($DisplayTaxes),
        'noTaxesMessage'            => $Shop->get('VATreleasedMessage', $LanguageID),
        'deliveryThresholdIsActive' => $Formatter->bool($Shop->get('DeliveryThresholdIsActive')),
        'countryCode2'              => $Code2,
    };

}

1;
