#========================================================================================
# package      DE_EPAGES::Zettle::API::Constants
# state        private
#----------------------------------------------------------------------------------------
# description  constants for cartridge
#========================================================================================
package DE_EPAGES::Zettle::API::Constants;
use base Exporter;

use strict;

our @EXPORT_OK = qw (
    INTERNAL_CARTRIDGE_NAME
    ZETTLE_OBJECT_ALIAS
    ZETTLE_ENVIRONMENT_CLASS
    ALLOWED_EXPORT_INTERVALS
    APP_SCOPES
    API_PARTNER_ID
    API_MAX_NAME_LENGTH
    API_MAX_DESCRIPTION_LENGTH
    %INITIAL_EXPORT_STATUS
    VALIDATION_TOKEN_KEY
    ZETTLE_HOME_URL
    ZETTLE_ATTRIBUTES_PROFILE
    IMAGE_LARGE_PROFILE
    WAIT_INTERVAL_AFTER_DELETE
    ZETTLE_TAXATION_TYPE_NONE
    ZETTLE_TAXATION_TYPE_VAT
    ZETTLE_TAXATION_TYPE_SALES_TAX
);

# This name is used to load objects from database (DON'T CHANGE!)
use constant INTERNAL_CARTRIDGE_NAME => 'Zettle';

# Name of the shop attribute which references the environment object (DON'T CHANGE!)
use constant ZETTLE_OBJECT_ALIAS => 'Zettle';

# Name of class that stores Zettle-related information (DON'T CHANGE!)
use constant ZETTLE_ENVIRONMENT_CLASS => 'ZettleEnvironment';

# Valid export intervals for 'Update interval' selection in Scheduled Export section
use constant ALLOWED_EXPORT_INTERVALS => [ 1, 3, 7, 30 ];

# See "iZettle Partner Integrations: Solution Documentation" page 27, section 4.3.3. Permission Scopes
# Scope parameter: https://github.com/iZettle/api-documentation/blob/master/authorization.adoc#ask-the-user-to-authorize-the-client
use constant APP_SCOPES => qw(
    READ:USERINFO
    READ:PRODUCT
    WRITE:PRODUCT
);

# Identifier provided by Simona Pappalardo via email
use constant API_PARTNER_ID => 'epages';

use constant API_MAX_NAME_LENGTH => 256;
use constant API_MAX_DESCRIPTION_LENGTH => 1024;

our %INITIAL_EXPORT_STATUS = (
    'FAILED' => -1,
    'PENDING' => 0,
    'RUNNING' => 1,
    'COMPLETED' => 2,
);

use constant VALIDATION_TOKEN_KEY => 'ValidationToken';

use constant ZETTLE_HOME_URL => 'https://www.zettle.com';

# LastUpdateProfile used to keep track of changes in product attributes of interest for Zettle export
use constant ZETTLE_ATTRIBUTES_PROFILE => 'ZettleAttributes';
# LastUpdateProfile used to keep track of changes in product image for Zettle export
use constant IMAGE_LARGE_PROFILE => 'ImageLarge';

# Zettle has a known bug when performing initial export after deleting products from Zettle. We need to wait the specified number of seconds
use constant WAIT_INTERVAL_AFTER_DELETE => 5;

# ZETTLE TAXATION TYPES: see DE_EPAGES/Zettle/Documents/API/ZettlePartnerDocumentation-Extracts.md, section 4.4.1.1. Taxation Types
# This constant indicates that Zettle merchant account doesn't apply VAT or sales tx to the product prices.
use constant ZETTLE_TAXATION_TYPE_NONE => 'NONE';
# This constant indicates that Zettle merchant account is configured to use country-specific VAT rates
use constant ZETTLE_TAXATION_TYPE_VAT => 'VAT';
# This constant indicates that Zettle merchant account is configured to use merchant-specific VAT rates
use constant ZETTLE_TAXATION_TYPE_SALES_TAX => 'SALES_TAX';

1;
