#========================================================================================
# package      DE_EPAGES::Zettle::DAL::mysql::Zettle
# state        private
# description  MySQL database interface for tables:
#               <ul>
#                   <li>zettledelete
#               </ul>
#========================================================================================
package DE_EPAGES::Zettle::DAL::mysql::Zettle;
use base qw( DE_EPAGES::Zettle::DAL::SQL::Zettle );

use strict;

use DE_EPAGES::Core::API::PerlTools qw ( GetCurrentDateTime );

#========================================================================================
# function     InsertZettleDelete
#----------------------------------------------------------------------------------------
# syntax       $Package->InsertZettleDelete($dbh, $hParameter);
#----------------------------------------------------------------------------------------
# description  Inserts an entry into table zettledelete.
#----------------------------------------------------------------------------------------
# input        $dbi | database handle | DE_EPAGES::Database::API::DBI
# input        $hParameter | with following keys:
#               <ul>
#                  <li>GUID          - GUID of the deleted object (primary key)- varchar(36)
#                  <li>SiteID        - Site ID              - int
#                  <li>ClassID       - Class ID. This should be a generic class like "Product" rather than a sub class like "Jacket". - int
#                  <li>PathFromSite  - Object Path relative to the object site. - varchar(1000)
#                  <li>ZettleUUID    - Zettle UUID of the deleted object - varchar(36)
#                  <li>DeletedOn     - Date and time of the deletion on an object - datetime
#               </ul> | ref.hash
#========================================================================================
sub InsertZettleDelete {
    my $self = shift;
    my ($dbi, $hParameter) = @_;
    $dbi->do('INSERT INTO zettledelete (guid, siteid, classid, pathfromsite, zettleuuid, deletedon) VALUES (?, ?, ?, ?, ?)',
        [ @{$hParameter}{qw( GUID SiteID ClassID PathFromSite ZettleUUID DeletedOn )} ]
    );
}

#========================================================================================
# function     SetZettleDeleted
#----------------------------------------------------------------------------------------
# syntax       $Package->SetZettleDeleted($dbi, $hParameter);
#----------------------------------------------------------------------------------------
# description  Writes an object into the zettledeleted table with the current time.
#----------------------------------------------------------------------------------------
# input        $dbi | database handle | DE_EPAGES::Database::API::DBI
# input        $hParameter | with following keys:
#               <ul>
#                  <li>GUID          - GUID of the deleted object (primary key)- varchar(36)
#                  <li>SiteID        - Site ID              - int
#                  <li>ClassID       - Class ID. This should be a generic class like "Product" rather than a sub class like "Jacket". - int
#                  <li>PathFromSite  - Object Path relative to the object site. - varchar(1000)
#                  <li>ZettleUUID    - Zettle UUID of the deleted object - varchar(36)
#               </ul> | ref.hash
#========================================================================================
sub SetZettleDeleted {
    my $self = shift;
    my ($dbi, $hParameter) = @_;

    my $Now = GetCurrentDateTime();

    my $sql = <<'END_SQL';
INSERT INTO zettledelete (guid, siteid, classid, pathfromsite, zettleuuid, deletedon)
VALUES (?, ?, ?, ?, ?, ?)
ON DUPLICATE KEY UPDATE siteid=?, classid=?, pathfromsite=?, zettleuuid=?, deletedon=?
END_SQL
    $dbi->do( $sql, [ @{$hParameter}{qw( GUID SiteID ClassID PathFromSite ZettleUUID )}, $Now, @{$hParameter}{qw( SiteID ClassID PathFromSite ZettleUUID )}, $Now ] );
}

1;
