# CONTENTS
This document contains extracts of interest from Zettle API documentation, which consists in several
HTML pages and Swagger docs.
The documentation comprises all available Zettle endpoints but the main document can be found here:
[iZettle public API documentation](https://github.com/iZettle/api-documentation)

Each of the endpoints has it's own section and also a Swagger documentation with details regarding
API methods and data models:
1. Authorization:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/authorization.adoc)
2. Finance:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/finance.adoc)
3. Giftcard:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/giftcard.adoc)
4. Image:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/image.adoc)
    2. [Swagger](https://image.izettle.com/swagger)
5. Inventory: https://github.com/iZettle/api-documentation/blob/master/inventory.adoc
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/inventory.adoc)
    2. [Swagger](https://inventory.izettle.com/swagger)
6. Products: https://github.com/iZettle/api-documentation/blob/master/product-library.adoc
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/product-library.adoc)
    2. [Swagger](https://products.izettle.com/swagger)
7. Purchase:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/purchase.adoc)

# EXTRACTS

## 4.2.1.2. Sample BulkProductImageUpload response
In `DE_EPAGES::Zettle::API::WebService::ImageService::bulkUploadImages` method we upload images to Zettle.
The response model is specified in *Responses > Model > BulkImageUploadResponse*
in  [Bulk product image upload](https://image.izettle.com/swagger#/images/uploadProductImageBulk).

Below is a sample response:
```
{
    'uploaded' => [
        {
            'source' => 'https://epnow-01.upango.es/WebRoot/Store/Shops/zettle-gb/60D6/5943/7F69/9FB7/B4CB/B976/395F/7FC6/frame.jpg',
            'imageLookupKey' => 'GlLiqIJNEeusyKr6Jki1nw-YKWnhgKXEeyEogOnBds16g',
            'imageUrls' => [
                'https://image.izettle.com/product/GlLiqIJNEeusyKr6Jki1nw-YKWnhgKXEeyEogOnBds16g.jpeg'
            ]
        },
        {
            'source' => 'https://epages.com/wp-content/uploads/2018/10/start-page-demoshop-en-6.jpg',
            'imageLookupKey' => 'GlLiqIJNEeusyKr6Jki1nw-YKWpbgKXEeyWKpedX5Vo1Q',
            'imageUrls' => [
                'https://image.izettle.com/product/GlLiqIJNEeusyKr6Jki1nw-YKWpbgKXEeyWKpedX5Vo1Q.jpeg'
            ]
        }
    ],
    'invalid' => [
        'http://bs927.serverbs.com/WebRoot/StorePIM/Shops/PimShop/Products/demo1/demo1.jpg',
        'http://bs927.serverbs.com/WebRoot/StorePIM/Shops/PimShop/Products/demo2/demo2.jpg'
    ]
};
```

## 6.2.3.3. Unused ProductDTO fields
When creating product DTO for exporting to Zettle, there are a number of fields/methods that are
unused for the moment but may be useful in the future.
See method `DE_EPAGES::Zettle::API::WebService::DTO::DTOFactory::buildProductDTO`.

The list of fields present in Zettle model but unused is:
- $ProductDTO->online($Online);
- $ProductDTO->categories($MainCategory);
- $ProductDTO->presentation($ProductPresentation);
- $ProductDTO->taxCode($TaxCode);
- $ProductDTO->category($Category);
- $ProductDTO->taxRates($TaxRates);
- $ProductDTO->taxExempt($TaxExempt);

For more details regarding API see *Request body > Schema > BulkImportRequest > FullProductUpdateRequest*
in  [Bulk product import](https://products.izettle.com/swagger#/import/importLibraryV2).


## 6.2.7.5. Delete a list of products: limitations
The API call to bulk delete products can be found [here](https://products.izettle.com/swagger#/products/deleteProducts).
URL length recommendations say maximum length should be 2048 characters which substracting 57 (delete URL length)
and divided by 42 (length of "&uuid=<PRODUCT-UUID>") results in 47 approx.
See method `DE_EPAGES::Zettle::API::WebService::ProductService::deleteProducts`.

Following recommendations we should make batches of 45 products (leaving some margin for changes in delete URL).

Bulk delete failed when processing too many products. See example below:
```
'DELETE https://products.izettle.com/organizations/self/products?uuid=6139f2ca-1112-100a-28e9-b976395fe102&uuid=6139f2ca-ce83-1029-2688-b976395fe148&uuid=6139f2c8-8808-1034-21a3-b976395fe188&uuid=6139ee98-3ca4-104c-2542-b976395fb61e&uuid=6139ee96-1589-1058-2b34-b976395fb690&uuid=6139ee96-5926-105d-219f-b976395fb686&uuid=6139ee98-cfa5-10ac-2475-b976395fb6ee&uuid=6139ee97-ce5d-10bd-20f4-b976395fb692&uuid=6139f2c7-30e7-10e1-2097-b976395fe15a&uuid=6139ee96-49e6-10f7-2f37-b976395fb6cb&uuid=6139f2c7-5423-10fd-2be4-b976395fe1ad&uuid=6139f2c7-60ff-1100-21f9-b976395fe1a2&uuid=6139f2c7-2497-111a-2c19-b976395fe158&uuid=6139ee99-869c-1133-2bc1-b976395fb642&uuid=6139f2c9-8e10-1148-2d4d-b976395fe127&uuid=6139ee95-7aaf-115f-2769-b976395fb68e&uuid=6139f2c8-ad59-1185-239b-b976395fe160&uuid=6139f2c7-d320-11a4-289c-b976395fe16d&uuid=6139f2c7-59d4-11bd-2ba1-b976395fe13e&uuid=6139f2ca-3caf-11c5-2da6-b976395fe1ed&uuid=6139f2ca-10f2-121a-2d91-b976395fe1a2&uuid=6139f2c8-3683-1222-2c11-b976395fe152&uuid=6139f2ca-a772-1245-2daf-b976395fe138&uuid=6139f2c8-4a16-124d-2a23-b976395fe11e&uuid=6139ee96-9867-1260-2fda-b976395fb60f&uuid=6139f2c6-2be1-126f-2544-b976395fe17d&uuid=6139ee96-181a-127c-250f-b976395fb65d&uuid=6139f2c6-befd-127f-2f00-b976395fe123&uuid=6139ee95-11bd-128c-2518-b976395fb610&uuid=6139ee98-2f06-129d-2824-b976395fb6d8&uuid=6139f2c9-038a-12bd-2cb3-b976395fe149&uuid=6139ee98-6836-12fe-262e-b976395fb688&uuid=6139f2c6-753a-133d-292c-b976395fe13f&uuid=6139ee95-1647-133e-2a8d-b976395fb631&uuid=6139ee98-e9fd-1349-24b2-b976395fb63a&uuid=6139f2c9-2190-135c-2ff2-b976395fe1af&uuid=6139ee96-b117-1367-22fb-b976395fb62f&uuid=6139f2c7-2c79-13c0-2d4f-b976395fe1d6&uuid=6139f2c7-a78d-13c4-2157-b976395fe169&uuid=6139f2c8-53fc-13c7-2b48-b976395fe114&uuid=6139ee99-9f4e-13c9-259a-b976395fb68b&uuid=6139ee95-1b28-13dd-2fd6-b976395fb627&uuid=6139f2c6-b438-13f9-2f3d-b976395fe187&uuid=6139ee98-c73e-13fb-2008-b976395fb608&uuid=6139f2c9-3f1a-1402-2285-b976395fe1f6&uuid=6139ee99-f6ff-1417-25b8-b976395fb62f&uuid=6139ee9a-650a-143b-27c8-b976395fb620&uuid=6139ee99-5236-1446-25be-b976395fb6d7&uuid=6139ee96-88d5-145a-26a3-b976395fb616&uuid=6139f2c6-c35b-147d-233c-b976395fe1e8&uuid=6139ee99-ed67-1480-21a3-b976395fb6a7&uuid=6139f2c7-e6a2-149f-2b85-b976395fe182&uuid=6139ee96-6c5a-14a5-204d-b976395fb609&uuid=6139f2c9-9562-14d5-289e-b976395fe147&uuid=6139ee97-1392-14d6-2372-b976395fb6a8&uuid=6139f2c5-941e-14e4-24ac-b976395fe1b7&uuid=6139f2ca-0b4c-14eb-2550-b976395fe121&uuid=6139ee95-6e6a-14ff-2ad9-b976395fb6c5&uuid=6139f2c6-a3aa-1512-2148-b976395fe14b&uuid=6139f2c9-4169-151d-2c25-b976395fe132&uuid=6139f2c8-a8c9-1540-2cb2-b976395fe1f9&uuid=6139ee97-6eff-1547-2a8a-b976395fb6c3&uuid=6139f2c8-8247-1566-22e8-b976395fe1d0&uuid=6139ee96-fc51-1566-2345-b976395fb6ad&uuid=6139ee98-18d6-1567-237f-b976395fb68b&uuid=6139f2c7-71a1-1571-2894-b976395fe1bc&uuid=6139ee9a-0e88-157c-2ec8-b976395fb6d0&uuid=6139f2c7-86ea-158e-283b-b976395fe13e&uuid=6139f2c9-6e8d-15bb-2393-b976395fe103&uuid=6139ee95-a4f1-15c2-2829-b976395fb61b&uuid=6139f2c8-160a-15ca-2097-b976395fe1e3&uuid=6139f2c8-5f65-15cd-240e-b976395fe1c5&uuid=6139ee9a-51e5-15d4-2752-b976395fb6be&uuid=6139f2c7-d9b5-15e1-2f47-b976395fe12c&uuid=6139ee98-c544-15f4-2452-b976395fb63f&uuid=6139f2c7-ddc6-15fe-2389-b976395fe10d&uuid=6139f2c8-39a7-1616-2a26-b976395fe16b&uuid=6139ee97-ab8d-1647-2225-b976395fb6b7&uuid=6139ee96-9327-165b-27ce-b976395fb60a&uuid=6139f2c6-d201-1669-2703-b976395fe1d8&uuid=6139f2c9-199b-166e-29b1-b976395fe159&uuid=6139f2c6-c949-166f-2b5d-b976395fe1f8&uuid=6139f2c9-87b8-1679-275c-b976395fe1cb&uuid=6139ee98-2e61-1682-2edb-b976395fb616&uuid=6139f2c7-b832-1688-286c-b976395fe121&uuid=6139f2c5-5237-16a1-2d57-b976395fe1e8&uuid=6139ee99-7564-16be-2893-b976395fb621&uuid=6139ee99-1a79-16ca-2916-b976395fb67d&uuid=6139ee97-177e-16cd-238d-b976395fb6ef&uuid=6139f2ca-7d19-1750-2010-b976395fe1ed&uuid=6139ee98-7652-178c-2b25-b976395fb6bf&uuid=6139ee98-cb49-1848-2b4f-b976395fb6bf&uuid=6139ee98-8236-1851-2ee8-b976395fb6c4&uuid=6139f2c6-f2f5-185d-2371-b976395fe13b&uuid=6139ee99-2ee1-188f-2b14-b976395fb687&uuid=6139ee96-07a3-18a2-2797-b976395fb6de&uuid=6139ee96-66ba-18a5-29c8-b976395fb6f3&uuid=6139ee96-2ba6-18aa-284c-b976395fb6d1&uuid=6139f2c8-c7cc-18cd-2d8e-b976395fe18f&uuid=6139f2ca-6b35-18dc-2e17-b976395fe1ba&uuid=6139ee96-967e-1900-2774-b976395fb633&uuid=6139f2ca-113e-1920-2072-b976395fe13b&uuid=6139ee95-72ce-192c-2e2c-b976395fb6b8&uuid=6139f2c9-c485-1931-2fcf-b976395fe177&uuid=6139f2c8-783d-1957-2081-b976395fe121&uuid=6139ee96-eff2-1967-2ccd-b976395fb62e&uuid=6139f2c9-9f47-1997-2e9b-b976395fe147&uuid=6139f2c7-2f78-19c0-2a48-b976395fe157&uuid=6139ee95-5140-19eb-2e0b-b976395fb684&uuid=6139f2c6-0e2d-1a58-24a1-b976395fe105&uuid=6139ee99-4b84-1a5d-2d9c-b976395fb6cd&uuid=6139ee99-619f-1a66-27b9-b976395fb634&uuid=6139ee97-a489-1a87-21b5-b976395fb6bb&uuid=6139ee96-0383-1a8b-2099-b976395fb6d0&uuid=6139f2c6-a578-1ab9-225f-b976395fe178&uuid=6139f2ca-cfe8-1ad6-2726-b976395fe164&uuid=6139f2ca-e149-1af9-234e-b976395fe1c7&uuid=6139ee98-ffd8-1b03-25e0-b976395fb683&uuid=6139f2c6-96bf-1b04-2ff7-b976395fe1de&uuid=6139ee96-8e59-1b05-2f01-b976395fb677&uuid=6139ee99-d4c1-1b05-21b1-b976395fb6ec&uuid=6139f2c9-414a-1b16-2e88-b976395fe120&uuid=6139f2ca-9547-1b1a-2c5b-b976395fe128&uuid=6139ee95-e3e2-1b23-2410-b976395fb666&uuid=6139ee96-f285-1b27-2e6b-b976395fb67c&uuid=6139ee95-219f-1b4a-2d52-b976395fb6d3&uuid=6139f2c9-4b8b-1b51-2460-b976395fe112&uuid=6139ee97-7c47-1b56-2050-b976395fb6ec&uuid=6139f2c6-57e3-1b66-2848-b976395fe174&uuid=6139ee98-67c1-1b85-21e1-b976395fb6ee&uuid=6139ee95-0666-1b91-23d7-b976395fb6d2&uuid=6139ee98-75c7-1b9e-2b82-b976395fb6c5&uuid=6139f2c6-7fda-1ba0-2b2a-b976395fe1d7&uuid=6139f2c7-81d7-1ba0-29bc-b976395fe1a4&uuid=6139ee97-76ac-1bac-2791-b976395fb65d&uuid=6139f2c6-d2c5-1bbf-2631-b976395fe164&uuid=6139f2c9-8723-1bc9-246d-b976395fe15e&uuid=6139ee97-f3e6-1bca-217a-b976395fb62d&uuid=6139ee94-4522-1bd5-2f9b-b976395fb675&uuid=6139ee99-6116-1be6-217e-b976395fb6fe&uuid=6139f2c6-daef-1bf9-28b3-b976395fe179&uuid=6139ee97-ec06-1bfe-2738-b976395fb694&uuid=6139f2c8-3b0f-1c08-266a-b976395fe182&uuid=6139ee99-e814-1c48-2711-b976395fb686&uuid=6139f2c8-e461-1c5e-233a-b976395fe10e&uuid=6139f2c8-6780-1c77-2d71-b976395fe1db&uuid=6139ee95-3fd4-1c91-256f-b976395fb692&uuid=6139f2ca-18f6-1cb9-2216-b976395fe17b&uuid=6139f2c6-3b20-1ccd-2fbc-b976395fe19a&uuid=6139ee99-b1a8-1ce4-2c7e-b976395fb695&uuid=6139f2c8-f084-1cf3-25fe-b976395fe1c9&uuid=6139f2ca-1063-1d31-21a3-b976395fe135&uuid=6139f2c7-7ab8-1d3a-2136-b976395fe10a&uuid=6139ee95-8fc9-1d3d-2351-b976395fb63a&uuid=6139f2c6-58c1-1d51-2bb1-b976395fe1f2&uuid=6139ee97-7c0a-1d7b-2307-b976395fb69c&uuid=6139ee98-fe84-1d84-2798-b976395fb648&uuid=6139ee98-f2a6-1dea-25e5-b976395fb67f&uuid=6139ee99-565e-1dec-23f4-b976395fb677&uuid=6139f2c8-3bfa-1dfa-284b-b976395fe12b&uuid=6139f2c7-ff50-1e06-24ff-b976395fe1d0&uuid=6139ee97-b2a2-1e33-23c3-b976395fb643&uuid=6139ee97-b03a-1e56-22ab-b976395fb6ec&uuid=6139ee97-22f5-1e5b-2ccc-b976395fb63c&uuid=6139ee97-78d7-1e6e-2de3-b976395fb61a&uuid=6139ee97-3374-1e85-2b26-b976395fb6bb&uuid=6139ee97-49b6-1e95-2d24-b976395fb694&uuid=6139f2c9-11bb-1ea2-27d8-b976395fe1e7&uuid=6139f2c6-3947-1ea9-2630-b976395fe128&uuid=6139ee99-5a59-1eb9-2c8a-b976395fb6de&uuid=6139f2c6-98c4-1ec1-2f59-b976395fe18e&uuid=6139ee97-ac84-1ec7-23a1-b976395fb6b9&uuid=6139ee98-0865-1ecc-2e53-b976395fb64d&uuid=6139f2c8-0433-1eed-265e-b976395fe140&uuid=6139f2ca-17d3-1f09-2aac-b976395fe1d1&uuid=6139ee99-fc8c-1f0a-2ec0-b976395fb64a&uuid=6139ee96-57af-1f0f-2049-b976395fb665&uuid=6139f2c7-fd56-1f1a-2c37-b976395fe14e&uuid=6139ee97-59fe-1f79-2f59-b976395fb6f7&uuid=6139f2c7-5c53-1fbc-296d-b976395fe134&uuid=6139ee99-c6e5-1fc5-2d75-b976395fb6a7&uuid=6139f2c9-e133-1fcb-2c19-b976395fe1a8&uuid=6139f2ca-741f-1fd2-2e92-b976395fe18b&uuid=6139ee99-5c82-1fe2-2800-b976395fb671
```

API response to previous request was:
```
'Response' => '<h1>Bad Message 431</h1><pre>reason: Request Header Fields Too Large</pre>',
   'Status' => 431,
   'StatusLine' => '431 Request Header Fields Too Large'
```

Zettle should update this API call so that data is not included as query parameters but as the body of the request instead.
The best option would be to use a JSON array, given that it would avoid the repetition of the "uuid=" part.