#!/bin/bash

# DESCRIPTION: disconnect Zettle application and remove tokens from ZettleEnvironment (default: STORENAME=Store, SHOPNAME=zettle-gb)

SCRIPTNAME=`basename $0`
DISCONNECT_URL="https://oauth.izettle.com/application-connections/self"

# Prompt coloring codes
YELLOW='\033[1;33m'
green='\033[0;32m'
blue='\033[0;34m'
NC='\033[0m'

# Shopname is read from 1st argument, if present. Default: zettle-gb
DEFAULT_SHOPNAME=zettle-gb
SHOPNAME=${1:-${DEFAULT_SHOPNAME}}
STORE=Store
# Load Zettle object alias from Constants.pm
ZETTLE_OBJECT_ALIAS=$($PERL -e "use DE_EPAGES::Zettle::API::Constants qw ( ZETTLE_OBJECT_ALIAS ); print ZETTLE_OBJECT_ALIAS();")
ZETTLE_ENV=/Shops/${SHOPNAME}/${ZETTLE_OBJECT_ALIAS}

# Show help message
if [ "${1}" == "-h" ] || [ "${1}" == "--help" ]; then
    echo -e "${green}Description${NC}: disconnect Zettle application and remove tokens from ZettleEnvironment"
    echo -e "${green}Usage${NC}: ${SCRIPTNAME} [SHOPNAME]"
    echo -e "\tSHOPNAME: Optional. Shop to be used (default: ${DEFAULT_SHOPNAME})"
    echo -e "${blue}Example${NC}: ${SCRIPTNAME} DemoShop"
    exit 0
fi

# Read AccessToken from ZettleEnvironment
ACCESS_TOKEN=`$PERL $EPAGES_CARTRIDGES/DE_EPAGES/Object/Scripts/get.pl -storename ${STORE} -path ${ZETTLE_ENV} AccessToken | head -1 | cut -d= -f2-`

if [ "${ACCESS_TOKEN}" == "undef" ]; then
    echo -e "AccessToken not available in ${ZETTLE_ENV} (application may already be disconnected or may not have been previously setup)"
    exit 1
fi

# Disconnect application from Zettle
echo -e "${YELLOW}[+] Revoking Zettle tokens...${NC}"
curl -i -X DELETE -H "Authorization: Bearer $ACCESS_TOKEN" $DISCONNECT_URL
echo
echo -e "${green}Note: proper disconnection returns '204 No Content'${NC}"

echo -e "${YELLOW}[+] Removing token data from ZettleEnvironment...${NC}"
# Remove AccessToken
REM_AT="$PERL $EPAGES_CARTRIDGES/DE_EPAGES/Object/Scripts/set.pl -storename ${STORE} -path ${ZETTLE_ENV} AccessToken=undef"
echo -e "${REM_AT}"
eval "${REM_AT}"
# Remove DeletToken
REM_RT="$PERL $EPAGES_CARTRIDGES/DE_EPAGES/Object/Scripts/set.pl -storename ${STORE} -path ${ZETTLE_ENV} RefreshToken=undef"
echo -e "${REM_RT}"
eval "${REM_RT}"
echo

exit 0