# CONTENTS
This document describes the workflow for the batch job that runs daily to launch scheduled updates and perform any necessary cleanup operations.

After a merchant connects the shop to Zettle a scheduled product export is automatically configured and can be adjusted by the merchant.<br/>
Not all product attributes are to be exported to Zettle so two new _LastUpdateProfiles_ are generated by the cartridge in order to keep track of any modification to any attributes of interest to Zettle export (see [Zettle-LastUpdateProfiles.md](Zettle-LastUpdateProfiles.md)).

# WORKFLOW

1. Collect all objects of class `ZettleEnvironment`.
2. For each instance:
    1. Check if account was disconnected and proceed to completely delete Zettle-related information.
    If merchant disconnected Zettle account we have to:
        - disconnect from API.
        - delete `Zettle` shop child.
    2. Check if scheduled export needs to be run according to the datetime when last product export was executed (`$Zettle->lastProductExport`) and also scheduled export frequency (`$Zettle->exportScheduleInterval`).<br/>
    We only consider the date part and leave out the time part because we cannot make any assumptions regarding the order in which the different _Zettle_ objects will be processed (see [Side Note A](#side-note-a))<br/>
    Export will be run for the shop if:
        ```
        date(`LastProductExport`)+`ExportScheduleInterval` >= date(Now()).
        ```

### Side Note A
Every time that an export process is run we register the timestamp when the process started in `LastProductExport` Zettle attribute.

The script configured in Scheduler would retrieve all instances of `ZettleEnvironment` classes and then it would loop all this objects to check:
- whether merchant disconnected from Zettle in which case we would delete all Zettle-related info for the associated shop/products.
- whether the _LastProductExport_ datetime tells us that we should run a new product export.<br/>
  The thing is that the order in which the different Zettle instances are processed is probably random, so an instance could be processed the first one day and processed the last the next day.

This means that we could find the following situation:
- Export for Shop1 runs this morning at 04:00:05 and this date <DATE1> is registered in _LastProductExport_ Zettle attribute.
- Export for ShopN runs this morning at 04:00:50 and this date is registered also <DATE2>.

Tomorrow the Scheduler runs the script but this time we have that:
- ShopN is processed in the first place at 04:00:03 and we check if LastProductExport+ExportScheduleInterval>=GetCurrentDateTime():<br/>
Assuming _ExportScheduleInteravl_ is configured to one day, we have that _DATE2_+24hours results in 04:00:50 which is not greater than current datetime.<br/>
This means the export for ShopN won't run at this point in time which means we're missing an export that should have been executed.

Leaving out the time part when comparing timestamps we can be sure that no export will be missed.