#==============================================================================
# package      DE_EPAGES::Zettle::Hooks::Attribute
# state        private
#==============================================================================
package DE_EPAGES::Zettle::Hooks::Attribute;

use DE_EPAGES::Object::API::Factory qw (GetRootObjectID);
use DE_EPAGES::ThirdPartyConfig::API::Constants qw (ATTRIBUTES_CATEGORY_MISC);
use DE_EPAGES::Zettle::API::Constants qw (INTERNAL_CARTRIDGE_NAME);

use strict;

#========================================================================================
# function     OnGetThirdPartyConfigAttributes
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnGetThirdPartyConfigAttributes($hParams);
#----------------------------------------------------------------------------------------
# description  API_GetThirdPartyConfigAttributes triggered, register attributes to be
#               configured in PBO
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>AttributesCategory
#                   <li>LanguageID
#               </ul> | ref.hash.*
#========================================================================================
sub OnGetThirdPartyConfigAttributes {
    my ($hParams) = @_;

    return unless $hParams->{'AttributesCategory'} eq ATTRIBUTES_CATEGORY_MISC;

    my $RootObjectID = GetRootObjectID();

    push(@{$hParams->{'Attributes'}}, {
        'SectionID'   => INTERNAL_CARTRIDGE_NAME,
        'SectionName' => INTERNAL_CARTRIDGE_NAME,
        'Attributes' => [
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_Logging'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_LoggingInitialExport'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_RegisterURL'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_AdminURL'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_ImageEndpoint'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_OAuthEndpoint'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_ProductEndpoint'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_AppClientID'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_AppClientSecret'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_AppRedirectURL'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_LandingURL'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'Zettle_UTMParameters'},
        ]
    });

    return;
}

1;