#========================================================================================
# package      DE_EPAGES::Zettle::Hooks::Object
# state        public
# description  Deletes ZettleDelete objects when a class or a site is deleted.
#========================================================================================
package DE_EPAGES::Zettle::Hooks::Object;

use strict;

use DE_EPAGES::Zettle::API::Table::ZettleDelete;

#========================================================================================
# function     OnDeleteClass
#----------------------------------------------------------------------------------------
# synObject    OnDeleteClass( $hParams );
#----------------------------------------------------------------------------------------
# description  Removes ZettleDelete objects if the object class is deleted.
#----------------------------------------------------------------------------------------
# input        $hParams | primary key of Object class, key is
#               <ul>
#                   <li>ClassID
#               </ul> | ref.hash.*
#========================================================================================
sub OnDeleteClass {
    my ($hParams) = @_;
    
    my $ClassID = $hParams->{'ClassID'};
    DE_EPAGES::Zettle::API::Table::ZettleDelete::OnDeleteClass({ ClassID => $ClassID });
}

#========================================================================================
# function     OnDeleteSite
#----------------------------------------------------------------------------------------
# synObject    OnDeleteSite( $hParams );
#----------------------------------------------------------------------------------------
# description  Removes ZettleDelete objects if the object site is deleted.
#----------------------------------------------------------------------------------------
# input        $hParams | primary key of object Site, key is
#               <ul>
#                   <li>SiteID
#               </ul> | ref.hash.*
#========================================================================================
sub OnDeleteSite {
    my ($hParams) = @_;
    
    my $SiteID = $hParams->{'SiteID'};
    DE_EPAGES::Zettle::API::Table::ZettleDelete::OnDeleteSite({ SiteID => $SiteID });
}

1;
